
--- Automatically sets the player role
--
-- The player's role will automatically be set when entering the world, or 
-- when changing specs. This affects both the role used to queue for groups, 
-- and the role in the current group, if any.

--- Sets the player role according to the active specialization.
local function _SetPlayerRole()

	role = "NONE"
		
	-- A nil specialization id indicates that no specialization has 
	-- been selected for the active talent group.
	
	specId = GetSpecialization()
	if specId then
		_, _, _, _, _, role = GetSpecializationInfo(specId)
	end

	-- If the role somehow comes back as nil, force it to NONE to ensure
	-- the checks and formatting below behave appropriately. This may 
	-- happen when the player is entering the world.
	
	if not role then
		role = "NONE"
	end

	currentRole = UnitGroupRolesAssigned("player")
	if currentRole == role then
		return
	end

	UnitSetRole("player", role)

	tank = (role == "TANK")
	healer = (role == "HEALER")
	damage = (role == "DAMAGER")
	SetLFGRoles(true, tank, healer, damage)
	
	ChatFrame_DisplaySystemMessageInPrimary(("Set player role to %s."):format(role))
end

-- Construct the addon.
local addon = CreateFrame("Frame", "hcRoleBotFrame")

--- Dispatches events to this addon by calling the method with the 
-- same name as the given event.
function addon:OnEvent(event, ...)
	if self[event] then
		self[event](self, event, ...)
	end
end

-- Register the event handler and initial events.
addon:SetScript("OnEvent", addon.OnEvent)

--- Sets the player role after each loading screen.
function addon:PLAYER_ENTERING_WORLD(event)
	_SetPlayerRole()
end

--- Sets the player role after each specialization change.
function addon:PLAYER_SPECIALIZATION_CHANGED(event)
	_SetPlayerRole()
end

--- Registers role-related events once the addon is loaded.
-- The ADDON_LOADED event is unregistered to prevent redundant calls to this
-- handler.
function addon:ADDON_LOADED(event, name)
	if name ~= "hcRoleBot" then
		return
	end
		
	self:UnregisterAllEvents()

	self:RegisterEvent("PLAYER_ENTERING_WORLD")
	self:RegisterEvent("PLAYER_SPECIALIZATION_CHANGED")
end

addon:RegisterEvent("ADDON_LOADED")
